/*
 * Copyright (C) 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.ranging.oob;

import android.ranging.RangingDevice;

/**
 * Represents a handle to a ranging device, containing information about the device
 * and a transport handle for out-of-band communication.
 *
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class DeviceHandle implements android.os.Parcelable {

DeviceHandle() { throw new RuntimeException("Stub!"); }

public int describeContents() { throw new RuntimeException("Stub!"); }

/**
 * Returns the ranging device associated with this handle.
 *
 * @return The {@link android.ranging.RangingDevice RangingDevice} instance.
 */

@android.annotation.NonNull
public android.ranging.RangingDevice getRangingDevice() { throw new RuntimeException("Stub!"); }

/**
 * Returns the transport handle, if set, for communication.
 *
 * @return The {@link android.ranging.oob.TransportHandle TransportHandle} instance.
 */

@android.annotation.NonNull
public android.ranging.oob.TransportHandle getTransportHandle() { throw new RuntimeException("Stub!"); }

public java.lang.String toString() { throw new RuntimeException("Stub!"); }

public void writeToParcel(@android.annotation.NonNull android.os.Parcel dest, int flags) { throw new RuntimeException("Stub!"); }

@android.annotation.NonNull public static final android.os.Parcelable.Creator<android.ranging.oob.DeviceHandle> CREATOR;
static { CREATOR = null; }
/**
 * Builder class for creating instances of {@link android.ranging.oob.DeviceHandle DeviceHandle}.
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class Builder {

/**
 * Constructs a new {@link android.ranging.oob.DeviceHandle.Builder Builder} with the required {@link android.ranging.RangingDevice RangingDevice}
 * and {@link android.ranging.oob.TransportHandle TransportHandle}.
 *
 * @param rangingDevice the {@link android.ranging.RangingDevice RangingDevice}
 * @param transportHandle Implementation of {@link android.ranging.oob.TransportHandle TransportHandle} for sending/receiving
 * OOB data from peer
 * @throws java.lang.NullPointerException if either parameter is {@code null}.
 */

public Builder(@android.annotation.NonNull android.ranging.RangingDevice rangingDevice, @android.annotation.NonNull android.ranging.oob.TransportHandle transportHandle) { throw new RuntimeException("Stub!"); }

/**
 * Builds and returns a new {@link android.ranging.oob.DeviceHandle DeviceHandle} instance using the
 * parameters provided to this builder.
 *
 * @return a newly created {@link android.ranging.oob.DeviceHandle DeviceHandle} instance.
 */

@android.annotation.NonNull
public android.ranging.oob.DeviceHandle build() { throw new RuntimeException("Stub!"); }
}

}

